# Table of contents

- [Welcome](README.md)
- [Celo Overview](overview.md)

## Getting Started

- [Choosing a Network](getting-started/choosing-a-network.md)
- [Mainnet](getting-started/mainnet.md)
  - [Running a Validator](getting-started/running-a-validator-in-mainnet.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-mainnet.md)
- [Baklava Testnet](getting-started/baklava-testnet.md)
  - [Running a Validator](getting-started/running-a-validator-in-baklava.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-baklava.md)
- [Alfajores Testnet](getting-started/alfajores-testnet.md)
  - [Using the Mobile Wallet](getting-started/using-the-mobile-wallet.md)
  - [Getting an Account and Funds](getting-started/faucet.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-alfajores.md)
- [Validator Setup FAQ](getting-started/validator-troubleshooting-faq.md)
- [Glossary](GLOSSARY.md)

## CELO Owner Guide

- [Quick Start](celo-holder-guide/quick-start.md)
- [cUSD Owner Guide](celo-holder-guide/cusd.md)
- [Using a Ledger Wallet](celo-holder-guide/ledger.md)
- [Understanding ReleaseGold](celo-holder-guide/release-gold.md)
- [Voting for Validator Groups](celo-holder-guide/voting-validators.md)
- [Voting on Governance](celo-holder-guide/voting-governance.md)
- [Recovering CELO from an Ethereum Address](celo-holder-guide/eth-recovery.md)

## Validator Guide

- [Overview](validator-guide/overview.md)
- [Attestation Service](validator-guide/attestation-service.md)
- [Key Management](validator-guide/key-management/summary.md)
  - [Detailed Role Descriptions](validator-guide/key-management/detailed.md)
  - [Validator Signer Key Rotation](validator-guide/key-management/key-rotation.md)
- [Securing Celo Nodes and Services](validator-guide/securing-nodes-and-services.md)
- [Monitoring](validator-guide/monitoring.md)
- [Upgrading a Node](validator-guide/node-upgrades.md)
- [Validator Explorer](validator-guide/validator-explorer.md)
- [Celo Foundation Voting Policy](validator-guide/celo-foundation-voting-policy.md)

## Developer Guide

- [Overview](developer-resources/overview.md)
- [Code Examples](developer-resources/start.md)
  - [Sending CELO](developer-resources/walkthroughs/hellocelo.md)
  - [Deploy a Contract (local node)](developer-resources/walkthroughs/hellocontracts.md)
  - [Deploy a Contract (Forno)](developer-resources/walkthroughs/hello-contract-remote-node.md)
  - [DappKit Truffle Box](developer-resources/walkthroughs/hello-mobile-dapp.md)
  - [Using Windows](developer-resources/develop-on-windows.md)
  <!-- - [Building a dApp with Contracts on Celo]() -->
  <!-- - [The Celo Protocol]()
    - [Architecture]()
    - [Similarities with Ethereum]()
    - [Difference between Ethereum and Celo]()
      - [Mobile First]()
      - [Architectural Differences]()
        - [Validators, full node, light node]()
      - [Protocol Differences]()
        - [TX object - link to transactions]()
        - [fees in dollars- link to Paying for Gas in Tokens]()
      - [Development Differences]()
    - [dApps on Celo]()
      - [What is a dApp?]() -->
    <!-- - [Architecture]() -->
- [ContractKit](developer-resources/contractkit/README.md)
  - [Setup](developer-resources/contractkit/setup.md)
  - [Using the kit](developer-resources/contractkit/usage.md)
  - [Using Web3 from the Kit](developer-resources/contractkit/notes-web3-with-contractkit.md)
  - [Celo Core Contracts. Wrappers / Registry](developer-resources/contractkit/contracts-wrappers-registry.md)
  - [Querying on-chain identifiers with ODIS](developer-resources/contractkit/odis.md)
    <!-- - [Example of querying (web3, kit)]()
    - [Example of sending tx (kit)]() -->
  <!-- - [Using Truffle]()
    - [Setting up a Local node]()
    - [Option: Using CeloProvider with Truffle]() -->
- [DAppKit](developer-resources/dappkit/README.md)
    <!-- - [Going mobile first (true decentralization)]()
    - [dApps and Wallets - Signing Transactions]() -->
  - [Setup](developer-resources/dappkit/setup.md)
    <!-- - [React Native]()
    - [Expo]() -->
  - [Usage](developer-resources/dappkit/usage.md)
  <!-- - [Guide to Asset Custody]() -->
- [Forno](developer-resources/forno/README.md)
- [Local Development Chain w/ Protocol Contracts](developer-resources/walkthroughs/development-chain.md)
- [Celo for Ethereum Developers](developer-resources/celo-for-eth-devs.md)
- [Celo DApp Gallery](developer-resources/celo-dapp-gallery.md)
- [Integrations](developer-resources/integrations/integrations.md)
  - [General](developer-resources/integrations/general.md)
  - [Checklist](developer-resources/integrations/checklist.md)
  - [Custody](developer-resources/integrations/custody.md)
  - [Listings](developer-resources/integrations/listings.md)
  - [Using a Cloud HSM](developer-resources/integrations/cloud-hsm.md)
- [Reference](developer-resources/contractkit/reference/SUMMARY.md)
  <!-- contractkit-reference-start -->
  - [Globals](developer-resources/contractkit/reference/globals.md)
  - [Modules]()
    - [address-registry](developer-resources/contractkit/reference/modules/_address_registry_.md)
    - [AddressRegistry](developer-resources/contractkit/reference/classes/_address_registry_.addressregistry.md)
    - [base](developer-resources/contractkit/reference/modules/_base_.md)
    - [CeloContract](developer-resources/contractkit/reference/enums/_base_.celocontract.md)
    - [contract-cache](developer-resources/contractkit/reference/modules/_contract_cache_.md)
    - [WrapperCache](developer-resources/contractkit/reference/classes/_contract_cache_.wrappercache.md)
    - [explorer/base](developer-resources/contractkit/reference/modules/_explorer_base_.md)
    - [ContractDetails](developer-resources/contractkit/reference/interfaces/_explorer_base_.contractdetails.md)
    - [explorer/block-explorer](developer-resources/contractkit/reference/modules/_explorer_block_explorer_.md)
    - [BlockExplorer](developer-resources/contractkit/reference/classes/_explorer_block_explorer_.blockexplorer.md)
    - [CallDetails](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.calldetails.md)
    - [ParsedBlock](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.parsedblock.md)
    - [ParsedTx](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.parsedtx.md)
    - [explorer/log-explorer](developer-resources/contractkit/reference/modules/_explorer_log_explorer_.md)
    - [LogExplorer](developer-resources/contractkit/reference/classes/_explorer_log_explorer_.logexplorer.md)
    - [governance/proposals](developer-resources/contractkit/reference/modules/_governance_proposals_.md)
    - [InteractiveProposalBuilder](developer-resources/contractkit/reference/classes/_governance_proposals_.interactiveproposalbuilder.md)
    - [ProposalBuilder](developer-resources/contractkit/reference/classes/_governance_proposals_.proposalbuilder.md)
    - [ProposalTransactionJSON](developer-resources/contractkit/reference/interfaces/_governance_proposals_.proposaltransactionjson.md)
    - [governance/proxy](developer-resources/contractkit/reference/modules/_governance_proxy_.md)
    - [identity/claims/account](developer-resources/contractkit/reference/modules/_identity_claims_account_.md)
    - [identity/claims/attestation-service-url](developer-resources/contractkit/reference/modules/_identity_claims_attestation_service_url_.md)
    - [identity/claims/claim](developer-resources/contractkit/reference/modules/_identity_claims_claim_.md)
    - [identity/claims/keybase](developer-resources/contractkit/reference/modules/_identity_claims_keybase_.md)
    - [identity/claims/types](developer-resources/contractkit/reference/modules/_identity_claims_types_.md)
    - [ClaimTypes](developer-resources/contractkit/reference/enums/_identity_claims_types_.claimtypes.md)
    - [identity/claims/verify](developer-resources/contractkit/reference/modules/_identity_claims_verify_.md)
    - [identity/metadata](developer-resources/contractkit/reference/modules/_identity_metadata_.md)
    - [IdentityMetadataWrapper](developer-resources/contractkit/reference/classes/_identity_metadata_.identitymetadatawrapper.md)
    - [identity/odis/bls-blinding-client](developer-resources/contractkit/reference/modules/_identity_odis_bls_blinding_client_.md)
    - [WasmBlsBlindingClient](developer-resources/contractkit/reference/classes/_identity_odis_bls_blinding_client_.wasmblsblindingclient.md)
    - [BlsBlindingClient](developer-resources/contractkit/reference/interfaces/_identity_odis_bls_blinding_client_.blsblindingclient.md)
    - [identity/odis/matchmaking](developer-resources/contractkit/reference/modules/_identity_odis_matchmaking_.md)
    - [identity/odis/phone-number-identifier](developer-resources/contractkit/reference/modules/_identity_odis_phone_number_identifier_.md)
    - [PhoneNumberHashDetails](developer-resources/contractkit/reference/interfaces/_identity_odis_phone_number_identifier_.phonenumberhashdetails.md)
    - [identity/odis/query](developer-resources/contractkit/reference/modules/_identity_odis_query_.md)
    - [AuthenticationMethod](developer-resources/contractkit/reference/enums/_identity_odis_query_.authenticationmethod.md)
    - [ErrorMessages](developer-resources/contractkit/reference/enums/_identity_odis_query_.errormessages.md)
    - [CustomSigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.customsigner.md)
    - [EncryptionKeySigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.encryptionkeysigner.md)
    - [MatchmakingRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.matchmakingrequest.md)
    - [MatchmakingResponse](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.matchmakingresponse.md)
    - [PhoneNumberPrivacyRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.phonenumberprivacyrequest.md)
    - [ServiceContext](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.servicecontext.md)
    - [SignMessageRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.signmessagerequest.md)
    - [SignMessageResponse](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.signmessageresponse.md)
    - [WalletKeySigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.walletkeysigner.md)
    - [identity/offchain-data-wrapper](developer-resources/contractkit/reference/modules/_identity_offchain_data_wrapper_.md)
    - [OffchainErrorTypes](developer-resources/contractkit/reference/enums/_identity_offchain_data_wrapper_.offchainerrortypes.md)
    - [OffchainDataWrapper](developer-resources/contractkit/reference/classes/_identity_offchain_data_wrapper_.offchaindatawrapper.md)
    - [identity/offchain/accessors/authorized-signer](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_authorized_signer_.md)
    - [AuthorizedSignerAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_authorized_signer_.authorizedsigneraccessor.md)
    - [identity/offchain/accessors/binary](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_binary_.md)
    - [PrivateBinaryAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_binary_.privatebinaryaccessor.md)
    - [PublicBinaryAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_binary_.publicbinaryaccessor.md)
    - [identity/offchain/accessors/errors](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_errors_.md)
    - [SchemaErrorTypes](developer-resources/contractkit/reference/enums/_identity_offchain_accessors_errors_.schemaerrortypes.md)
    - [InvalidDataError](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.invaliddataerror.md)
    - [InvalidKey](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.invalidkey.md)
    - [OffchainError](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.offchainerror.md)
    - [UnavailableKey](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.unavailablekey.md)
    - [UnknownCiphertext](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.unknownciphertext.md)
    - [identity/offchain/accessors/interfaces](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_interfaces_.md)
    - [PrivateAccessor](developer-resources/contractkit/reference/interfaces/_identity_offchain_accessors_interfaces_.privateaccessor.md)
    - [PublicAccessor](developer-resources/contractkit/reference/interfaces/_identity_offchain_accessors_interfaces_.publicaccessor.md)
    - [identity/offchain/accessors/name](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_name_.md)
    - [PrivateNameAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_name_.privatenameaccessor.md)
    - [PublicNameAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_name_.publicnameaccessor.md)
    - [identity/offchain/accessors/pictures](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_pictures_.md)
    - [PrivatePictureAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_pictures_.privatepictureaccessor.md)
    - [PublicPictureAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_pictures_.publicpictureaccessor.md)
    - [identity/offchain/accessors/simple](developer-resources/contractkit/reference/modules/_identity_offchain_accessors_simple_.md)
    - [PrivateSimpleAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_simple_.privatesimpleaccessor.md)
    - [PublicSimpleAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_simple_.publicsimpleaccessor.md)
    - [identity/offchain/storage-writers](developer-resources/contractkit/reference/modules/_identity_offchain_storage_writers_.md)
    - [GitStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.gitstoragewriter.md)
    - [GoogleStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.googlestoragewriter.md)
    - [LocalStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.localstoragewriter.md)
    - [MockStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.mockstoragewriter.md)
    - [StorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.storagewriter.md)
    - [identity/offchain/utils](developer-resources/contractkit/reference/modules/_identity_offchain_utils_.md)
    - [kit](developer-resources/contractkit/reference/modules/_kit_.md)
    - [ContractKit](developer-resources/contractkit/reference/classes/_kit_.contractkit.md)
    - [KitOptions](developer-resources/contractkit/reference/interfaces/_kit_.kitoptions.md)
    - [NetworkConfig](developer-resources/contractkit/reference/interfaces/_kit_.networkconfig.md)
    - [network-utils/genesis-block-utils](developer-resources/contractkit/reference/modules/_network_utils_genesis_block_utils_.md)
    - [GenesisBlockUtils](developer-resources/contractkit/reference/classes/_network_utils_genesis_block_utils_.genesisblockutils.md)
    - [network-utils/google-storage-utils](developer-resources/contractkit/reference/modules/_network_utils_google_storage_utils_.md)
    - [GoogleStorageUtils](developer-resources/contractkit/reference/classes/_network_utils_google_storage_utils_.googlestorageutils.md)
    - [network-utils/static-node-utils](developer-resources/contractkit/reference/modules/_network_utils_static_node_utils_.md)
    - [StaticNodeUtils](developer-resources/contractkit/reference/classes/_network_utils_static_node_utils_.staticnodeutils.md)
    - [providers/celo-provider](developer-resources/contractkit/reference/modules/_providers_celo_provider_.md)
    - [CeloProvider](developer-resources/contractkit/reference/classes/_providers_celo_provider_.celoprovider.md)
    - [test-utils/PromiEventStub](developer-resources/contractkit/reference/modules/_test_utils_promieventstub_.md)
    - [test-utils/setup.global](developer-resources/contractkit/reference/modules/_test_utils_setup_global_.md)
    - [test-utils/teardown.global](developer-resources/contractkit/reference/modules/_test_utils_teardown_global_.md)
    - [utils/array](developer-resources/contractkit/reference/modules/_utils_array_.md)
    - [utils/azure-key-vault-client](developer-resources/contractkit/reference/modules/_utils_azure_key_vault_client_.md)
    - [AzureKeyVaultClient](developer-resources/contractkit/reference/classes/_utils_azure_key_vault_client_.azurekeyvaultclient.md)
    - [utils/ber-utils](developer-resources/contractkit/reference/modules/_utils_ber_utils_.md)
    - [utils/ledger-utils](developer-resources/contractkit/reference/modules/_utils_ledger_utils_.md)
    - [utils/provider-utils](developer-resources/contractkit/reference/modules/_utils_provider_utils_.md)
    - [utils/rpc-caller](developer-resources/contractkit/reference/modules/_utils_rpc_caller_.md)
    - [DefaultRpcCaller](developer-resources/contractkit/reference/classes/_utils_rpc_caller_.defaultrpccaller.md)
    - [RpcCaller](developer-resources/contractkit/reference/interfaces/_utils_rpc_caller_.rpccaller.md)
    - [utils/signature-utils](developer-resources/contractkit/reference/modules/_utils_signature_utils_.md)
    - [Signature](developer-resources/contractkit/reference/classes/_utils_signature_utils_.signature.md)
    - [utils/signing-utils](developer-resources/contractkit/reference/modules/_utils_signing_utils_.md)
    - [RLPEncodedTx](developer-resources/contractkit/reference/interfaces/_utils_signing_utils_.rlpencodedtx.md)
    - [utils/timezone](developer-resources/contractkit/reference/modules/_utils_timezone_.md)
    - [Coordinates](developer-resources/contractkit/reference/interfaces/_utils_timezone_.coordinates.md)
    - [Timezone](developer-resources/contractkit/reference/interfaces/_utils_timezone_.timezone.md)
    - [utils/tx-params-normalizer](developer-resources/contractkit/reference/modules/_utils_tx_params_normalizer_.md)
    - [TxParamsNormalizer](developer-resources/contractkit/reference/classes/_utils_tx_params_normalizer_.txparamsnormalizer.md)
    - [utils/tx-result](developer-resources/contractkit/reference/modules/_utils_tx_result_.md)
    - [TransactionResult](developer-resources/contractkit/reference/classes/_utils_tx_result_.transactionresult.md)
    - [utils/tx-uri](developer-resources/contractkit/reference/modules/_utils_tx_uri_.md)
    - [utils/web3-utils](developer-resources/contractkit/reference/modules/_utils_web3_utils_.md)
    - [wallets/aws-hsm-wallet](developer-resources/contractkit/reference/modules/_wallets_aws_hsm_wallet_.md)
    - [AwsHsmWallet](developer-resources/contractkit/reference/classes/_wallets_aws_hsm_wallet_.awshsmwallet.md)
    - [wallets/azure-hsm-wallet](developer-resources/contractkit/reference/modules/_wallets_azure_hsm_wallet_.md)
    - [AzureHSMWallet](developer-resources/contractkit/reference/classes/_wallets_azure_hsm_wallet_.azurehsmwallet.md)
    - [wallets/ledger-utils/data](developer-resources/contractkit/reference/modules/_wallets_ledger_utils_data_.md)
    - [wallets/ledger-utils/tokens](developer-resources/contractkit/reference/modules/_wallets_ledger_utils_tokens_.md)
    - [API](developer-resources/contractkit/reference/interfaces/_wallets_ledger_utils_tokens_.api.md)
    - [TokenInfo](developer-resources/contractkit/reference/interfaces/_wallets_ledger_utils_tokens_.tokeninfo.md)
    - [wallets/ledger-wallet](developer-resources/contractkit/reference/modules/_wallets_ledger_wallet_.md)
    - [AddressValidation](developer-resources/contractkit/reference/enums/_wallets_ledger_wallet_.addressvalidation.md)
    - [LedgerWallet](developer-resources/contractkit/reference/classes/_wallets_ledger_wallet_.ledgerwallet.md)
    - [wallets/local-wallet](developer-resources/contractkit/reference/modules/_wallets_local_wallet_.md)
    - [LocalWallet](developer-resources/contractkit/reference/classes/_wallets_local_wallet_.localwallet.md)
    - [wallets/remote-wallet](developer-resources/contractkit/reference/modules/_wallets_remote_wallet_.md)
    - [RemoteWallet](developer-resources/contractkit/reference/classes/_wallets_remote_wallet_.remotewallet.md)
    - [wallets/rpc-wallet](developer-resources/contractkit/reference/modules/_wallets_rpc_wallet_.md)
    - [RpcWalletErrors](developer-resources/contractkit/reference/enums/_wallets_rpc_wallet_.rpcwalleterrors.md)
    - [RpcWallet](developer-resources/contractkit/reference/classes/_wallets_rpc_wallet_.rpcwallet.md)
    - [wallets/signers/aws-hsm-signer](developer-resources/contractkit/reference/modules/_wallets_signers_aws_hsm_signer_.md)
    - [AwsHsmSigner](developer-resources/contractkit/reference/classes/_wallets_signers_aws_hsm_signer_.awshsmsigner.md)
    - [wallets/signers/azure-hsm-signer](developer-resources/contractkit/reference/modules/_wallets_signers_azure_hsm_signer_.md)
    - [AzureHSMSigner](developer-resources/contractkit/reference/classes/_wallets_signers_azure_hsm_signer_.azurehsmsigner.md)
    - [wallets/signers/ledger-signer](developer-resources/contractkit/reference/modules/_wallets_signers_ledger_signer_.md)
    - [LedgerSigner](developer-resources/contractkit/reference/classes/_wallets_signers_ledger_signer_.ledgersigner.md)
    - [wallets/signers/local-signer](developer-resources/contractkit/reference/modules/_wallets_signers_local_signer_.md)
    - [LocalSigner](developer-resources/contractkit/reference/classes/_wallets_signers_local_signer_.localsigner.md)
    - [wallets/signers/rpc-signer](developer-resources/contractkit/reference/modules/_wallets_signers_rpc_signer_.md)
    - [RpcSigner](developer-resources/contractkit/reference/classes/_wallets_signers_rpc_signer_.rpcsigner.md)
    - [wallets/signers/signer](developer-resources/contractkit/reference/modules/_wallets_signers_signer_.md)
    - [Signer](developer-resources/contractkit/reference/interfaces/_wallets_signers_signer_.signer.md)
    - [wallets/test-utils](developer-resources/contractkit/reference/modules/_wallets_test_utils_.md)
    - [wallets/wallet](developer-resources/contractkit/reference/modules/_wallets_wallet_.md)
    - [WalletBase](developer-resources/contractkit/reference/classes/_wallets_wallet_.walletbase.md)
    - [ReadOnlyWallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.readonlywallet.md)
    - [UnlockableWallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.unlockablewallet.md)
    - [Wallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.wallet.md)
    - [web3-contract-cache](developer-resources/contractkit/reference/modules/_web3_contract_cache_.md)
    - [Web3ContractCache](developer-resources/contractkit/reference/classes/_web3_contract_cache_.web3contractcache.md)
    - [wrappers/Accounts](developer-resources/contractkit/reference/modules/_wrappers_accounts_.md)
    - [AccountsWrapper](developer-resources/contractkit/reference/classes/_wrappers_accounts_.accountswrapper.md)
    - [wrappers/Attestations](developer-resources/contractkit/reference/modules/_wrappers_attestations_.md)
    - [AttestationServiceStatusState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationservicestatusstate.md)
    - [AttestationState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationstate.md)
    - [AttestationsWrapper](developer-resources/contractkit/reference/classes/_wrappers_attestations_.attestationswrapper.md)
    - [ActionableAttestation](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.actionableattestation.md)
    - [AttestationServiceStatusResponse](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationservicestatusresponse.md)
    - [AttestationStat](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstat.md)
    - [AttestationStateForIssuer](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstateforissuer.md)
    - [AttestationsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationsconfig.md)
    - [AttestationsToken](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstoken.md)
    - [UnselectedRequest](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.unselectedrequest.md)
    - [wrappers/BaseSlasher](developer-resources/contractkit/reference/modules/_wrappers_baseslasher_.md)
    - [BaseSlasher](developer-resources/contractkit/reference/classes/_wrappers_baseslasher_.baseslasher.md)
    - [wrappers/BaseWrapper](developer-resources/contractkit/reference/modules/_wrappers_basewrapper_.md)
    - [BaseWrapper](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.basewrapper.md)
    - [CeloTransactionObject](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.celotransactionobject.md)
    - [Filter](developer-resources/contractkit/reference/interfaces/_wrappers_basewrapper_.filter.md)
    - [wrappers/BlockchainParameters](developer-resources/contractkit/reference/modules/_wrappers_blockchainparameters_.md)
    - [BlockchainParametersWrapper](developer-resources/contractkit/reference/classes/_wrappers_blockchainparameters_.blockchainparameterswrapper.md)
    - [BlockchainParametersConfig](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.blockchainparametersconfig.md)
    - [ClientVersion](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.clientversion.md)
    - [wrappers/DoubleSigningSlasher](developer-resources/contractkit/reference/modules/_wrappers_doublesigningslasher_.md)
    - [DoubleSigningSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_doublesigningslasher_.doublesigningslasherwrapper.md)
    - [wrappers/DowntimeSlasher](developer-resources/contractkit/reference/modules/_wrappers_downtimeslasher_.md)
    - [DowntimeSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_downtimeslasher_.downtimeslasherwrapper.md)
    - [DowntimeSlasherConfig](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.downtimeslasherconfig.md)
    - [Interval](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.interval.md)
    - [wrappers/Election](developer-resources/contractkit/reference/modules/_wrappers_election_.md)
    - [ElectionWrapper](developer-resources/contractkit/reference/classes/_wrappers_election_.electionwrapper.md)
    - [ElectableValidators](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electablevalidators.md)
    - [ElectionConfig](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electionconfig.md)
    - [GroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvote.md)
    - [GroupVoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvoterreward.md)
    - [ValidatorGroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.validatorgroupvote.md)
    - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voter.md)
    - [VoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voterreward.md)
    - [wrappers/Escrow](developer-resources/contractkit/reference/modules/_wrappers_escrow_.md)
    - [EscrowWrapper](developer-resources/contractkit/reference/classes/_wrappers_escrow_.escrowwrapper.md)
    - [wrappers/Exchange](developer-resources/contractkit/reference/modules/_wrappers_exchange_.md)
    - [ExchangeWrapper](developer-resources/contractkit/reference/classes/_wrappers_exchange_.exchangewrapper.md)
    - [ExchangeConfig](developer-resources/contractkit/reference/interfaces/_wrappers_exchange_.exchangeconfig.md)
    - [wrappers/Freezer](developer-resources/contractkit/reference/modules/_wrappers_freezer_.md)
    - [FreezerWrapper](developer-resources/contractkit/reference/classes/_wrappers_freezer_.freezerwrapper.md)
    - [wrappers/GasPriceMinimum](developer-resources/contractkit/reference/modules/_wrappers_gaspriceminimum_.md)
    - [GasPriceMinimumWrapper](developer-resources/contractkit/reference/classes/_wrappers_gaspriceminimum_.gaspriceminimumwrapper.md)
    - [GasPriceMinimumConfig](developer-resources/contractkit/reference/interfaces/_wrappers_gaspriceminimum_.gaspriceminimumconfig.md)
    - [wrappers/GoldTokenWrapper](developer-resources/contractkit/reference/modules/_wrappers_goldtokenwrapper_.md)
    - [GoldTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_goldtokenwrapper_.goldtokenwrapper.md)
    - [wrappers/Governance](developer-resources/contractkit/reference/modules/_wrappers_governance_.md)
    - [ProposalStage](developer-resources/contractkit/reference/enums/_wrappers_governance_.proposalstage.md)
    - [VoteValue](developer-resources/contractkit/reference/enums/_wrappers_governance_.votevalue.md)
    - [GovernanceWrapper](developer-resources/contractkit/reference/classes/_wrappers_governance_.governancewrapper.md)
    - [GovernanceConfig](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.governanceconfig.md)
    - [HotfixRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.hotfixrecord.md)
    - [ParticipationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.participationparameters.md)
    - [ProposalMetadata](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalmetadata.md)
    - [ProposalRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalrecord.md)
    - [ProposalStageDurations](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalstagedurations.md)
    - [UpvoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.upvoterecord.md)
    - [VoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voterecord.md)
    - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voter.md)
    - [Votes](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.votes.md)
    - [wrappers/LockedGold](developer-resources/contractkit/reference/modules/_wrappers_lockedgold_.md)
    - [LockedGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_lockedgold_.lockedgoldwrapper.md)
    - [AccountSlashed](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.accountslashed.md)
    - [LockedGoldConfig](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.lockedgoldconfig.md)
    - [PendingWithdrawal](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.pendingwithdrawal.md)
    - [VotingDetails](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.votingdetails.md)
    - [wrappers/MetaTransactionWallet](developer-resources/contractkit/reference/modules/_wrappers_metatransactionwallet_.md)
    - [MetaTransactionWalletWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwallet_.metatransactionwalletwrapper.md)
    - [RawTransaction](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.rawtransaction.md)
    - [TransactionObjectWithValue](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.transactionobjectwithvalue.md)
    - [wrappers/MetaTransactionWalletDeployer](developer-resources/contractkit/reference/modules/_wrappers_metatransactionwalletdeployer_.md)
    - [MetaTransactionWalletDeployerWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwalletdeployer_.metatransactionwalletdeployerwrapper.md)
    - [wrappers/MultiSig](developer-resources/contractkit/reference/modules/_wrappers_multisig_.md)
    - [MultiSigWrapper](developer-resources/contractkit/reference/classes/_wrappers_multisig_.multisigwrapper.md)
    - [TransactionData](developer-resources/contractkit/reference/interfaces/_wrappers_multisig_.transactiondata.md)
    - [wrappers/ReleaseGold](developer-resources/contractkit/reference/modules/_wrappers_releasegold_.md)
    - [ReleaseGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_releasegold_.releasegoldwrapper.md)
    - [BalanceState](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.balancestate.md)
    - [ReleaseGoldInfo](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.releasegoldinfo.md)
    - [wrappers/Reserve](developer-resources/contractkit/reference/modules/_wrappers_reserve_.md)
    - [ReserveWrapper](developer-resources/contractkit/reference/classes/_wrappers_reserve_.reservewrapper.md)
    - [ReserveConfig](developer-resources/contractkit/reference/interfaces/_wrappers_reserve_.reserveconfig.md)
    - [wrappers/SortedOracles](developer-resources/contractkit/reference/modules/_wrappers_sortedoracles_.md)
    - [MedianRelation](developer-resources/contractkit/reference/enums/_wrappers_sortedoracles_.medianrelation.md)
    - [SortedOraclesWrapper](developer-resources/contractkit/reference/classes/_wrappers_sortedoracles_.sortedoracleswrapper.md)
    - [MedianRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.medianrate.md)
    - [OracleRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclerate.md)
    - [OracleReport](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclereport.md)
    - [OracleTimestamp](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oracletimestamp.md)
    - [SortedOraclesConfig](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.sortedoraclesconfig.md)
    - [wrappers/StableTokenWrapper](developer-resources/contractkit/reference/modules/_wrappers_stabletokenwrapper_.md)
    - [StableTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_stabletokenwrapper_.stabletokenwrapper.md)
    - [InflationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.inflationparameters.md)
    - [StableTokenConfig](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.stabletokenconfig.md)
    - [wrappers/Validators](developer-resources/contractkit/reference/modules/_wrappers_validators_.md)
    - [ValidatorsWrapper](developer-resources/contractkit/reference/classes/_wrappers_validators_.validatorswrapper.md)
    - [GroupMembership](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.groupmembership.md)
    - [LockedGoldRequirements](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.lockedgoldrequirements.md)
    - [MembershipHistoryExtraData](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.membershiphistoryextradata.md)
    - [Validator](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validator.md)
    - [ValidatorGroup](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorgroup.md)
    - [ValidatorReward](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorreward.md)
    - [ValidatorsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorsconfig.md)
  - [Classes]()
    - [AddressRegistry](developer-resources/contractkit/reference/classes/_address_registry_.addressregistry.md)
    - [WrapperCache](developer-resources/contractkit/reference/classes/_contract_cache_.wrappercache.md)
    - [BlockExplorer](developer-resources/contractkit/reference/classes/_explorer_block_explorer_.blockexplorer.md)
    - [LogExplorer](developer-resources/contractkit/reference/classes/_explorer_log_explorer_.logexplorer.md)
    - [InteractiveProposalBuilder](developer-resources/contractkit/reference/classes/_governance_proposals_.interactiveproposalbuilder.md)
    - [ProposalBuilder](developer-resources/contractkit/reference/classes/_governance_proposals_.proposalbuilder.md)
    - [IdentityMetadataWrapper](developer-resources/contractkit/reference/classes/_identity_metadata_.identitymetadatawrapper.md)
    - [WasmBlsBlindingClient](developer-resources/contractkit/reference/classes/_identity_odis_bls_blinding_client_.wasmblsblindingclient.md)
    - [OffchainDataWrapper](developer-resources/contractkit/reference/classes/_identity_offchain_data_wrapper_.offchaindatawrapper.md)
    - [AuthorizedSignerAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_authorized_signer_.authorizedsigneraccessor.md)
    - [PrivateBinaryAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_binary_.privatebinaryaccessor.md)
    - [PublicBinaryAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_binary_.publicbinaryaccessor.md)
    - [InvalidDataError](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.invaliddataerror.md)
    - [InvalidKey](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.invalidkey.md)
    - [OffchainError](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.offchainerror.md)
    - [UnavailableKey](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.unavailablekey.md)
    - [UnknownCiphertext](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_errors_.unknownciphertext.md)
    - [PrivateNameAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_name_.privatenameaccessor.md)
    - [PublicNameAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_name_.publicnameaccessor.md)
    - [PrivatePictureAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_pictures_.privatepictureaccessor.md)
    - [PublicPictureAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_pictures_.publicpictureaccessor.md)
    - [PrivateSimpleAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_simple_.privatesimpleaccessor.md)
    - [PublicSimpleAccessor](developer-resources/contractkit/reference/classes/_identity_offchain_accessors_simple_.publicsimpleaccessor.md)
    - [GitStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.gitstoragewriter.md)
    - [GoogleStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.googlestoragewriter.md)
    - [LocalStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.localstoragewriter.md)
    - [MockStorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.mockstoragewriter.md)
    - [StorageWriter](developer-resources/contractkit/reference/classes/_identity_offchain_storage_writers_.storagewriter.md)
    - [ContractKit](developer-resources/contractkit/reference/classes/_kit_.contractkit.md)
    - [GenesisBlockUtils](developer-resources/contractkit/reference/classes/_network_utils_genesis_block_utils_.genesisblockutils.md)
    - [GoogleStorageUtils](developer-resources/contractkit/reference/classes/_network_utils_google_storage_utils_.googlestorageutils.md)
    - [StaticNodeUtils](developer-resources/contractkit/reference/classes/_network_utils_static_node_utils_.staticnodeutils.md)
    - [CeloProvider](developer-resources/contractkit/reference/classes/_providers_celo_provider_.celoprovider.md)
    - [AzureKeyVaultClient](developer-resources/contractkit/reference/classes/_utils_azure_key_vault_client_.azurekeyvaultclient.md)
    - [DefaultRpcCaller](developer-resources/contractkit/reference/classes/_utils_rpc_caller_.defaultrpccaller.md)
    - [Signature](developer-resources/contractkit/reference/classes/_utils_signature_utils_.signature.md)
    - [TxParamsNormalizer](developer-resources/contractkit/reference/classes/_utils_tx_params_normalizer_.txparamsnormalizer.md)
    - [TransactionResult](developer-resources/contractkit/reference/classes/_utils_tx_result_.transactionresult.md)
    - [AwsHsmWallet](developer-resources/contractkit/reference/classes/_wallets_aws_hsm_wallet_.awshsmwallet.md)
    - [AzureHSMWallet](developer-resources/contractkit/reference/classes/_wallets_azure_hsm_wallet_.azurehsmwallet.md)
    - [LedgerWallet](developer-resources/contractkit/reference/classes/_wallets_ledger_wallet_.ledgerwallet.md)
    - [LocalWallet](developer-resources/contractkit/reference/classes/_wallets_local_wallet_.localwallet.md)
    - [RemoteWallet](developer-resources/contractkit/reference/classes/_wallets_remote_wallet_.remotewallet.md)
    - [RpcWallet](developer-resources/contractkit/reference/classes/_wallets_rpc_wallet_.rpcwallet.md)
    - [AwsHsmSigner](developer-resources/contractkit/reference/classes/_wallets_signers_aws_hsm_signer_.awshsmsigner.md)
    - [AzureHSMSigner](developer-resources/contractkit/reference/classes/_wallets_signers_azure_hsm_signer_.azurehsmsigner.md)
    - [LedgerSigner](developer-resources/contractkit/reference/classes/_wallets_signers_ledger_signer_.ledgersigner.md)
    - [LocalSigner](developer-resources/contractkit/reference/classes/_wallets_signers_local_signer_.localsigner.md)
    - [RpcSigner](developer-resources/contractkit/reference/classes/_wallets_signers_rpc_signer_.rpcsigner.md)
    - [WalletBase](developer-resources/contractkit/reference/classes/_wallets_wallet_.walletbase.md)
    - [Web3ContractCache](developer-resources/contractkit/reference/classes/_web3_contract_cache_.web3contractcache.md)
    - [AccountsWrapper](developer-resources/contractkit/reference/classes/_wrappers_accounts_.accountswrapper.md)
    - [AttestationsWrapper](developer-resources/contractkit/reference/classes/_wrappers_attestations_.attestationswrapper.md)
    - [BaseSlasher](developer-resources/contractkit/reference/classes/_wrappers_baseslasher_.baseslasher.md)
    - [BaseWrapper](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.basewrapper.md)
    - [CeloTransactionObject](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.celotransactionobject.md)
    - [BlockchainParametersWrapper](developer-resources/contractkit/reference/classes/_wrappers_blockchainparameters_.blockchainparameterswrapper.md)
    - [DoubleSigningSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_doublesigningslasher_.doublesigningslasherwrapper.md)
    - [DowntimeSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_downtimeslasher_.downtimeslasherwrapper.md)
    - [ElectionWrapper](developer-resources/contractkit/reference/classes/_wrappers_election_.electionwrapper.md)
    - [EscrowWrapper](developer-resources/contractkit/reference/classes/_wrappers_escrow_.escrowwrapper.md)
    - [ExchangeWrapper](developer-resources/contractkit/reference/classes/_wrappers_exchange_.exchangewrapper.md)
    - [FreezerWrapper](developer-resources/contractkit/reference/classes/_wrappers_freezer_.freezerwrapper.md)
    - [GasPriceMinimumWrapper](developer-resources/contractkit/reference/classes/_wrappers_gaspriceminimum_.gaspriceminimumwrapper.md)
    - [GoldTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_goldtokenwrapper_.goldtokenwrapper.md)
    - [GovernanceWrapper](developer-resources/contractkit/reference/classes/_wrappers_governance_.governancewrapper.md)
    - [LockedGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_lockedgold_.lockedgoldwrapper.md)
    - [MetaTransactionWalletWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwallet_.metatransactionwalletwrapper.md)
    - [MetaTransactionWalletDeployerWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwalletdeployer_.metatransactionwalletdeployerwrapper.md)
    - [MultiSigWrapper](developer-resources/contractkit/reference/classes/_wrappers_multisig_.multisigwrapper.md)
    - [ReleaseGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_releasegold_.releasegoldwrapper.md)
    - [ReserveWrapper](developer-resources/contractkit/reference/classes/_wrappers_reserve_.reservewrapper.md)
    - [SortedOraclesWrapper](developer-resources/contractkit/reference/classes/_wrappers_sortedoracles_.sortedoracleswrapper.md)
    - [StableTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_stabletokenwrapper_.stabletokenwrapper.md)
    - [ValidatorsWrapper](developer-resources/contractkit/reference/classes/_wrappers_validators_.validatorswrapper.md)
  - [Enums]()
    - [CeloContract](developer-resources/contractkit/reference/enums/_base_.celocontract.md)
    - [ClaimTypes](developer-resources/contractkit/reference/enums/_identity_claims_types_.claimtypes.md)
    - [AuthenticationMethod](developer-resources/contractkit/reference/enums/_identity_odis_query_.authenticationmethod.md)
    - [ErrorMessages](developer-resources/contractkit/reference/enums/_identity_odis_query_.errormessages.md)
    - [OffchainErrorTypes](developer-resources/contractkit/reference/enums/_identity_offchain_data_wrapper_.offchainerrortypes.md)
    - [SchemaErrorTypes](developer-resources/contractkit/reference/enums/_identity_offchain_accessors_errors_.schemaerrortypes.md)
    - [AddressValidation](developer-resources/contractkit/reference/enums/_wallets_ledger_wallet_.addressvalidation.md)
    - [RpcWalletErrors](developer-resources/contractkit/reference/enums/_wallets_rpc_wallet_.rpcwalleterrors.md)
    - [AttestationServiceStatusState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationservicestatusstate.md)
    - [AttestationState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationstate.md)
    - [ProposalStage](developer-resources/contractkit/reference/enums/_wrappers_governance_.proposalstage.md)
    - [VoteValue](developer-resources/contractkit/reference/enums/_wrappers_governance_.votevalue.md)
    - [MedianRelation](developer-resources/contractkit/reference/enums/_wrappers_sortedoracles_.medianrelation.md)
  - [Interfaces]()
    - [ContractDetails](developer-resources/contractkit/reference/interfaces/_explorer_base_.contractdetails.md)
    - [CallDetails](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.calldetails.md)
    - [ParsedBlock](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.parsedblock.md)
    - [ParsedTx](developer-resources/contractkit/reference/interfaces/_explorer_block_explorer_.parsedtx.md)
    - [ProposalTransactionJSON](developer-resources/contractkit/reference/interfaces/_governance_proposals_.proposaltransactionjson.md)
    - [BlsBlindingClient](developer-resources/contractkit/reference/interfaces/_identity_odis_bls_blinding_client_.blsblindingclient.md)
    - [PhoneNumberHashDetails](developer-resources/contractkit/reference/interfaces/_identity_odis_phone_number_identifier_.phonenumberhashdetails.md)
    - [CustomSigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.customsigner.md)
    - [EncryptionKeySigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.encryptionkeysigner.md)
    - [MatchmakingRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.matchmakingrequest.md)
    - [MatchmakingResponse](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.matchmakingresponse.md)
    - [PhoneNumberPrivacyRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.phonenumberprivacyrequest.md)
    - [ServiceContext](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.servicecontext.md)
    - [SignMessageRequest](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.signmessagerequest.md)
    - [SignMessageResponse](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.signmessageresponse.md)
    - [WalletKeySigner](developer-resources/contractkit/reference/interfaces/_identity_odis_query_.walletkeysigner.md)
    - [PrivateAccessor](developer-resources/contractkit/reference/interfaces/_identity_offchain_accessors_interfaces_.privateaccessor.md)
    - [PublicAccessor](developer-resources/contractkit/reference/interfaces/_identity_offchain_accessors_interfaces_.publicaccessor.md)
    - [KitOptions](developer-resources/contractkit/reference/interfaces/_kit_.kitoptions.md)
    - [NetworkConfig](developer-resources/contractkit/reference/interfaces/_kit_.networkconfig.md)
    - [RpcCaller](developer-resources/contractkit/reference/interfaces/_utils_rpc_caller_.rpccaller.md)
    - [RLPEncodedTx](developer-resources/contractkit/reference/interfaces/_utils_signing_utils_.rlpencodedtx.md)
    - [Coordinates](developer-resources/contractkit/reference/interfaces/_utils_timezone_.coordinates.md)
    - [Timezone](developer-resources/contractkit/reference/interfaces/_utils_timezone_.timezone.md)
    - [API](developer-resources/contractkit/reference/interfaces/_wallets_ledger_utils_tokens_.api.md)
    - [TokenInfo](developer-resources/contractkit/reference/interfaces/_wallets_ledger_utils_tokens_.tokeninfo.md)
    - [Signer](developer-resources/contractkit/reference/interfaces/_wallets_signers_signer_.signer.md)
    - [ReadOnlyWallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.readonlywallet.md)
    - [UnlockableWallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.unlockablewallet.md)
    - [Wallet](developer-resources/contractkit/reference/interfaces/_wallets_wallet_.wallet.md)
    - [ActionableAttestation](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.actionableattestation.md)
    - [AttestationServiceStatusResponse](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationservicestatusresponse.md)
    - [AttestationStat](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstat.md)
    - [AttestationStateForIssuer](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstateforissuer.md)
    - [AttestationsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationsconfig.md)
    - [AttestationsToken](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstoken.md)
    - [UnselectedRequest](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.unselectedrequest.md)
    - [Filter](developer-resources/contractkit/reference/interfaces/_wrappers_basewrapper_.filter.md)
    - [BlockchainParametersConfig](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.blockchainparametersconfig.md)
    - [ClientVersion](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.clientversion.md)
    - [DowntimeSlasherConfig](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.downtimeslasherconfig.md)
    - [Interval](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.interval.md)
    - [ElectableValidators](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electablevalidators.md)
    - [ElectionConfig](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electionconfig.md)
    - [GroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvote.md)
    - [GroupVoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvoterreward.md)
    - [ValidatorGroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.validatorgroupvote.md)
    - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voter.md)
    - [VoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voterreward.md)
    - [ExchangeConfig](developer-resources/contractkit/reference/interfaces/_wrappers_exchange_.exchangeconfig.md)
    - [GasPriceMinimumConfig](developer-resources/contractkit/reference/interfaces/_wrappers_gaspriceminimum_.gaspriceminimumconfig.md)
    - [GovernanceConfig](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.governanceconfig.md)
    - [HotfixRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.hotfixrecord.md)
    - [ParticipationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.participationparameters.md)
    - [ProposalMetadata](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalmetadata.md)
    - [ProposalRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalrecord.md)
    - [ProposalStageDurations](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalstagedurations.md)
    - [UpvoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.upvoterecord.md)
    - [VoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voterecord.md)
    - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voter.md)
    - [Votes](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.votes.md)
    - [AccountSlashed](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.accountslashed.md)
    - [LockedGoldConfig](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.lockedgoldconfig.md)
    - [PendingWithdrawal](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.pendingwithdrawal.md)
    - [VotingDetails](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.votingdetails.md)
    - [RawTransaction](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.rawtransaction.md)
    - [TransactionObjectWithValue](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.transactionobjectwithvalue.md)
    - [TransactionData](developer-resources/contractkit/reference/interfaces/_wrappers_multisig_.transactiondata.md)
    - [BalanceState](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.balancestate.md)
    - [ReleaseGoldInfo](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.releasegoldinfo.md)
    - [ReserveConfig](developer-resources/contractkit/reference/interfaces/_wrappers_reserve_.reserveconfig.md)
    - [MedianRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.medianrate.md)
    - [OracleRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclerate.md)
    - [OracleReport](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclereport.md)
    - [OracleTimestamp](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oracletimestamp.md)
    - [SortedOraclesConfig](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.sortedoraclesconfig.md)
    - [InflationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.inflationparameters.md)
    - [StableTokenConfig](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.stabletokenconfig.md)
    - [GroupMembership](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.groupmembership.md)
    - [LockedGoldRequirements](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.lockedgoldrequirements.md)
    - [MembershipHistoryExtraData](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.membershiphistoryextradata.md)
    - [Validator](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validator.md)
    - [ValidatorGroup](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorgroup.md)
    - [ValidatorReward](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorreward.md)
    - [ValidatorsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorsconfig.md)
  <!-- contractkit-reference-end -->

## Celo Codebase

- [Celo Protocol](celo-codebase/protocol/README.md)
  - [Consensus](celo-codebase/protocol/consensus/README.md)
    - [Validator Set Differences](celo-codebase/protocol/consensus/validator-set-differences.md)
    - [Locating Nodes](celo-codebase/protocol/consensus/locating-nodes.md)
    - [Ultralight Sync](celo-codebase/protocol/consensus/ultralight-sync.md)
  - [Proof-of-Stake](celo-codebase/protocol/proof-of-stake/README.md)
    - [Validator Groups](celo-codebase/protocol/proof-of-stake/validator-groups.md)
    - [Locked Gold and Voting](celo-codebase/protocol/proof-of-stake/locked-gold.md)
    - [Validator Elections](celo-codebase/protocol/proof-of-stake/validator-elections.md)
    - [Epoch Rewards](celo-codebase/protocol/proof-of-stake/epoch-rewards.md)
      - [Rewards for Validators and Validator Groups](celo-codebase/protocol/proof-of-stake/validator-rewards.md)
      - [Rewards for Locked Gold Holders](celo-codebase/protocol/proof-of-stake/locked-gold-rewards.md)
      - [Community Fund](celo-codebase/protocol/proof-of-stake/community-fund.md)
      - [Carbon Offsetting Fund](celo-codebase/protocol/proof-of-stake/carbon-offsetting-fund.md)
    - [Penalties](celo-codebase/protocol/proof-of-stake/penalties.md)
  - [Governance](celo-codebase/protocol/governance.md)
  - [Stability Mechanism](celo-codebase/protocol/stability/README.md)
    - [Stability Algorithm \(CP-DOTO\)](celo-codebase/protocol/stability/doto.md)
    - [Oracles](celo-codebase/protocol/stability/oracles.md)
    - [Stability Fees](celo-codebase/protocol/stability/stability-fees.md)
    - [Tobin Tax](celo-codebase/protocol/stability/tobin-tax.md)
  - [Transactions](celo-codebase/protocol/transactions/README.md)
    - [Native Currency](celo-codebase/protocol/transactions/native-currency.md)
    - [Paying for Gas in Tokens](celo-codebase/protocol/transactions/erc20-transaction-fees.md)
    - [Gas Pricing](celo-codebase/protocol/transactions/gas-pricing.md)
    - [Escrow](celo-codebase/protocol/transactions/escrow.md)
    - [Encrypted Payment Comments](celo-codebase/protocol/transactions/tx-comment-encyption.md)
    - [Full Node Incentives](celo-codebase/protocol/transactions/full-node-incentives.md)
  - [Identity](celo-codebase/protocol/identity/README.md)
    - [Phone Number Privacy](celo-codebase/protocol/identity/phone-number-privacy.md)
    - [Metadata](celo-codebase/protocol/identity/metadata.md)
    - [Randomness](celo-codebase/protocol/identity/randomness.md)
- [Celo Wallet](celo-codebase/wallet/README.md)
  - [Running the Wallet Locally](celo-codebase/wallet/intro.md)
  - [Wallet Functionality](celo-codebase/wallet/how-the-wallet-works/README.md)
    - [Verification](celo-codebase/wallet/how-the-wallet-works/verification.md)
    - [Invitations](celo-codebase/wallet/how-the-wallet-works/invitations.md)
    - [Payments and Exchanging](celo-codebase/wallet/how-the-wallet-works/sending-and-requesting-payments.md)
    - [Ultralight Node Sync](celo-codebase/wallet/how-the-wallet-works/ultralight-node-sync.md)

## Command Line Interface

- [Introduction](command-line-interface/introduction.md)
- [Commands](command-line-interface/commands.md)
  - [Account](command-line-interface/account.md)
  - [Config](command-line-interface/config.md)
  - [DKG](command-line-interface/dkg.md)
  - [Election](command-line-interface/election.md)
  - [Exchange](command-line-interface/exchange.md)
  - [Governance](command-line-interface/governance.md)
  - [Identity](command-line-interface/identity.md)
  - [LockedGold](command-line-interface/lockedgold.md)
  - [Multisig](command-line-interface/multisig.md)
  - [Network](command-line-interface/network.md)
  - [Node](command-line-interface/node.md)
  - [Oracle](command-line-interface/oracle.md)
  - [ReleaseGold](command-line-interface/releasegold.md)
  - [Reserve](command-line-interface/reserve.md)
  - [Rewards](command-line-interface/rewards.md)
  - [Transfer](command-line-interface/transfer.md)
  - [Validator](command-line-interface/validator.md)
  - [ValidatorGroup](command-line-interface/validatorgroup.md)
  - [Help](command-line-interface/help.md)

## Community

- [Code of Conduct](community/code-of-conduct.md)
- [Contributing](community/contributing.md)
- [Grant Playbook](community/grant-playbook.md)
- [Release Process](community/release-process/README.md)
  - [Smart Contracts](community/release-process/smart-contracts.md)
  - [Blockchain Client](community/release-process/blockchain-client.md)
  - [Base, Celocli, ContractKit, DAppKit, and Utils](community/release-process/base-cli-contractkit-dappkit-utils.md)
  - [Attestation Service](community/release-process/attestation-service.md)

## Important Information

- [Alfajores Testnet Disclaimer](important-information/alfajores-testnet-disclaimer.md)
- [Baklava Testnet Disclaimer](important-information/baklava-testnet-disclaimer.md)
- [Mainnet Disclaimer](important-information/mainnet-network-disclaimer.md)
